From 39fb3aa3df9633fca393212df9be2efc6c2f9fdc Mon Sep 17 00:00:00 2001
From: Jacob Champion <jacob.champion@enterprisedb.com>
Date: Fri, 2 May 2025 09:44:43 -0700
Subject: [PATCH] oauth: Correct SSL dependency for libpq-oauth.a

libpq-oauth.a includes libpq-int.h, which includes OpenSSL headers. The
Autoconf side picks up the necessary include directories via CPPFLAGS,
but Meson needs the dependency to be made explicit.

Reported-by: Nathan Bossart <nathandbossart@gmail.com>
Discussion: https://postgr.es/m/aBTgjDfrdOZmaPgv%40nathan
---
 src/interfaces/libpq-oauth/meson.build | 6 +++++-
 1 file changed, 5 insertions(+), 1 deletion(-)

diff --git a/src/interfaces/libpq-oauth/meson.build b/src/interfaces/libpq-oauth/meson.build
index 9e7301a7f63..df064c59a40 100644
--- a/src/interfaces/libpq-oauth/meson.build
+++ b/src/interfaces/libpq-oauth/meson.build
@@ -25,7 +25,11 @@ libpq_oauth_st = static_library('libpq-oauth',
   libpq_oauth_sources,
   include_directories: [libpq_oauth_inc, postgres_inc],
   c_pch: pch_postgres_fe_h,
-  dependencies: [frontend_stlib_code, libpq_oauth_deps],
+  dependencies: [
+    frontend_stlib_code,
+    libpq_oauth_deps,
+    ssl, # libpq-int.h includes OpenSSL headers
+  ],
   kwargs: default_lib_args,
 )
 
-- 
2.34.1

